/*
 * Copyright (C) 1999, 2000, 2002  Lorenzo Bettini <bettini@gnu.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

// decorators for xhtml

#ifndef XHTMLDECORATOR_H
#define XHTMLDECORATOR_H

#include "htmldecorator.h"

class XhtmlTagDecorator : public TagDecorator
{
 public:
  XhtmlTagDecorator( TextGenerator *t, CharTranslator *, 
                     const string &ta, const string &a,
                     const string &v );

 protected:
  virtual void generateAttrVal() const;
};

class XhtmlColorDecorator : public XhtmlTagDecorator
{
 public:
  XhtmlColorDecorator( TextGenerator *t, CharTranslator *, const string &color );
};

#endif
